import * as i0 from '@angular/core';
import { EventEmitter, Component, Input, Output, TemplateRef, ElementRef, ContentChild, ViewChild, ViewChildren, NgModule } from '@angular/core';
import * as i1 from '@angular/common';
import { CommonModule } from '@angular/common';
import * as i2 from 'ng-devui/popover';
import { PopoverModule } from 'ng-devui/popover';
import { FormsModule } from '@angular/forms';

class TagComponent {
    constructor() {
        this.labelStyle = '';
        this.customColor = '';
        // @deprecated
        this.deletable = false;
        this.mode = 'default';
        this.checked = false;
        /**
         * tag被删除后触发
         */
        this.tagDelete = new EventEmitter();
        this.checkedChange = new EventEmitter();
        this.deleteTag = false;
        this.colorMap = {
            'blue-w98': '#3383ff',
            'aqua-w98': '#39afcc',
            'olivine-w98': '#2fa898',
            'green-w98': '#4eb15e',
            'yellow-w98': '#b08d1a',
            'orange-w98': '#d47f35',
            'red-w98': '#f66f6a',
            'pink-w98': '#f3689a',
            'purple-w98': '#a97af8',
        };
    }
    get isColorfulTag() {
        return !!(this.colorMap[this.labelStyle] || (this.customColor && this.customColor !== ''));
    }
    ngOnChanges(changes) {
        const { tag } = changes;
        if (tag) {
            this.currentTag = typeof this.tag === 'string' ? this.tag : '';
        }
    }
    removeTag($event, tag) {
        this.canDeleteTag(tag).then((canDelete) => {
            if (!canDelete) {
                return;
            }
            this.deleteTag = true;
            this.tagDelete.emit({ tag: tag, event: $event });
        });
    }
    tagClick() {
        if (this.mode === 'checkable') {
            this.checked = !this.checked;
            this.checkedChange.emit(this.checked);
        }
    }
    canDeleteTag(tag) {
        let closeResult = Promise.resolve(true);
        if (this.beforeDelete) {
            const result = this.beforeDelete(tag);
            if (typeof result !== 'undefined') {
                if (result.then) {
                    closeResult = result;
                }
                else if (result.subscribe) {
                    closeResult = result.toPromise();
                }
                else {
                    closeResult = Promise.resolve(result);
                }
            }
        }
        return closeResult;
    }
}
TagComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "15.1.5", ngImport: i0, type: TagComponent, deps: [], target: i0.ɵɵFactoryTarget.Component });
TagComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "15.1.5", type: TagComponent, selector: "d-tag", inputs: { tag: "tag", labelStyle: "labelStyle", customColor: "customColor", deletable: "deletable", titleContent: "titleContent", mode: "mode", checked: "checked", maxWidth: "maxWidth", customViewTemplate: "customViewTemplate", beforeDelete: "beforeDelete" }, outputs: { tagDelete: "tagDelete", checkedChange: "checkedChange" }, exportAs: ["Tag"], usesOnChanges: true, ngImport: i0, template: "<span\n  class=\"devui-tag-item {{ labelStyle }}\"\n  [style.display]=\"deleteTag ? 'none' : 'block'\"\n  [ngClass]=\"{\n    'devui-colorful-tag': isColorfulTag,\n    'devui-selected-tag': checked,\n    'devui-deletable-tag': mode === 'closeable' || deletable,\n    'devui-checkable-tag': mode === 'checkable'\n  }\"\n  [ngStyle]=\"{\n    'border-color': customColor,\n    'background-color': isColorfulTag ? (checked ? customColor : '') : '',\n    color: isColorfulTag ? (checked ? '#fff' : customColor) : '',\n    cursor: this.mode === 'checkable' ? 'pointer' : ''\n  }\"\n  title=\"{{ titleContent ? titleContent : currentTag }}\"\n  (click)=\"tagClick()\"\n>\n  <div class=\"content-wrapper\" [ngStyle]=\"{ 'background-color': colorMap[labelStyle] || customColor }\"></div>\n  <span *ngIf=\"!customViewTemplate\" [class.devui-max-width-tag]=\"maxWidth\" [style.maxWidth]=\"maxWidth ? maxWidth : ''\">{{\n    currentTag\n  }}</span>\n  <ng-template *ngIf=\"customViewTemplate\" [ngTemplateOutlet]=\"customViewTemplate\" [ngTemplateOutletContext]=\"{ tag: tag }\"></ng-template>\n  <a\n    class=\"remove-button\"\n    [ngClass]=\"{ 'default-button': !isColorfulTag }\"\n    *ngIf=\"mode === 'closeable' || deletable\"\n    (click)=\"removeTag($event, tag)\"\n  >\n    <svg\n      *ngIf=\"isColorfulTag\"\n      width=\"12px\"\n      height=\"12px\"\n      viewBox=\"0 0 16 16\"\n      version=\"1.1\"\n      xmlns=\"http://www.w3.org/2000/svg\"\n      xmlns:xlink=\"http://www.w3.org/1999/xlink\"\n    >\n      <g stroke=\"none\" stroke-width=\"1\" fill=\"none\" fill-rule=\"evenodd\">\n        <polygon\n          [ngStyle]=\"{ fill: isColorfulTag ? (checked ? '#fff' : customColor) : '' }\"\n          fill=\"#293040\"\n          fill-rule=\"nonzero\"\n          points=\"8 6.58578644 12.2426407 2.34314575 13.6568542 3.75735931 9.41421356 8 13.6568542 12.2426407 12.2426407 13.6568542 8 9.41421356 3.75735931 13.6568542 2.34314575 12.2426407 6.58578644 8 2.34314575 3.75735931 3.75735931 2.34314575\"\n        ></polygon>\n      </g>\n    </svg>\n    <svg\n      *ngIf=\"!isColorfulTag\"\n      width=\"12px\"\n      height=\"12px\"\n      viewBox=\"0 0 12 12\"\n      version=\"1.1\"\n      xmlns=\"http://www.w3.org/2000/svg\"\n      xmlns:xlink=\"http://www.w3.org/1999/xlink\"\n    >\n      <g stroke=\"none\" stroke-width=\"1\" fill=\"none\" fill-rule=\"evenodd\">\n        <path\n          d=\"M8.86785321,3.13214679 C9.02624037,3.29053395 9.02624037,3.54733027 8.86785321,3.70571743 L6.573,6 L8.86785321,8.29428257 C9.02624037,8.45266973 9.02624037,8.70946605 8.86785321,8.86785321 C8.70946605,9.02624037 8.45266973,9.02624037 8.29428257,8.86785321 L6,6.573 L3.70571743,8.86785321 C3.54733027,9.02624037 3.29053395,9.02624037 3.13214679,8.86785321 C2.97375963,8.70946605 2.97375963,8.45266973 3.13214679,8.29428257 L5.427,6 L3.13214679,3.70571743 C2.97375963,3.54733027 2.97375963,3.29053395 3.13214679,3.13214679 C3.29053395,2.97375963 3.54733027,2.97375963 3.70571743,3.13214679 L6,5.427 L8.29428257,3.13214679 C8.45266973,2.97375963 8.70946605,2.97375963 8.86785321,3.13214679 Z\"\n          fill-rule=\"nonzero\"\n        ></path>\n      </g>\n    </svg>\n  </a>\n</span>\n", styles: [".devui-font-size-base{font-size:12px;font-size:var(--devui-font-size, 12px)}.devui-font-base{font-size:12px;font-size:var(--devui-font-size, 12px);font-weight:400;font-weight:var(--devui-font-content-weight, normal);line-height:1.5;line-height:var(--devui-line-height-base, 1.5)}.devui-font-size-modal-title{font-size:18px;font-size:var(--devui-font-size-modal-title, 18px)}.devui-font-modal-title{font-size:18px;font-size:var(--devui-font-size-modal-title, 18px);font-weight:700;font-weight:var(--devui-font-title-weight, bold);line-height:1.5;line-height:var(--devui-line-height-base, 1.5)}.devui-font-size-page-title{font-size:16px;font-size:var(--devui-font-size-page-title, 16px)}.devui-font-page-title{font-size:16px;font-size:var(--devui-font-size-page-title, 16px);font-weight:700;font-weight:var(--devui-font-title-weight, bold);line-height:1.5;line-height:var(--devui-line-height-base, 1.5)}.devui-font-size-secondary-title{font-size:14px;font-size:var(--devui-font-size-card-title, 14px)}.devui-font-secondary-title{font-size:14px;font-size:var(--devui-font-size-card-title, 14px);font-weight:700;font-weight:var(--devui-font-title-weight, bold);line-height:1.5;line-height:var(--devui-line-height-base, 1.5)}:host{display:inline-block;position:relative}.devui-tag-item{padding:0 8px;min-height:20px;font-size:12px;font-size:var(--devui-font-size, 12px);line-height:20px;color:#71757f;color:var(--devui-aide-text, #71757f);background-color:#e9edfa;background-color:var(--devui-label-bg, #e9edfa);border-radius:2px;border-radius:var(--devui-border-radius, 2px);border-width:0;border-style:solid;border-color:inherit;display:block;align-items:center;position:relative;cursor:default}.devui-tag-item .content-wrapper{pointer-events:none;position:absolute;width:100%;height:100%;border:1px solid transparent;top:0;left:0;opacity:0}.devui-tag-item span{vertical-align:0}.devui-tag-item:hover:not(.devui-colorful-tag):not(.devui-selected-tag).devui-checkable-tag{color:#252b3a;color:var(--devui-aide-text-hover, #252b3a)}.devui-tag-item:hover:not(.devui-colorful-tag):not(.devui-selected-tag).devui-checkable-tag .remove-button svg polygon{fill:#7693f5;fill:var(--devui-brand-hover, #7693f5)}.devui-tag-item:hover.devui-checkable-tag .content-wrapper{opacity:.08}.devui-tag-item.devui-selected-tag{color:#252b3a;color:var(--devui-aide-text-hover, #252b3a)}.devui-tag-item.devui-selected-tag .remove-button svg polygon{fill:#526ecc;fill:var(--devui-brand-active, #526ecc)}.devui-tag-item .remove-button{margin-left:12px;font-size:16px;font-size:var(--devui-font-size-icon, 16px);cursor:pointer;width:12px;height:12px;line-height:12px;border-radius:50%;display:inline-block;text-align:center;position:absolute;top:50%;transform:translateY(-50%)}.devui-tag-item .remove-button svg polygon{fill:#71757f;fill:var(--devui-icon-fill, #71757f)}.devui-tag-item .remove-button:hover{text-decoration:none;font-size:16px;font-size:var(--devui-font-size-icon, 16px)}.devui-tag-item .default-button{margin-left:12px;font-size:16px;font-size:var(--devui-font-size-icon, 16px);cursor:pointer;width:12px;height:12px;line-height:12px;background-color:#d7d8da;background-color:var(--devui-shape-icon-fill, #d7d8da);border-radius:50%;display:inline-block;text-align:center;transition:background-color cubic-bezier(.645,.045,.355,1) .3s;transition:background-color var(--devui-animation-ease-in-out-smooth, cubic-bezier(.645, .045, .355, 1)) var(--devui-animation-duration-slow, .3s)}.devui-tag-item .default-button svg path{fill:#fff;fill:var(--devui-light-text, #ffffff)}.devui-tag-item .default-button:hover{text-decoration:none;background-color:#babbc0;background-color:var(--devui-shape-icon-fill-hover, #babbc0)}.devui-deletable-tag{padding-right:32px}.devui-colorful-tag{height:18px;line-height:18px;border-width:1px;background-color:#fff;background-color:var(--devui-base-bg, #ffffff)}.blue-w98{color:#0b81f6;background-color:#fff;background-color:var(--devui-base-bg, #ffffff);border-width:1px;border-color:#0b81f6}.blue-w98 .remove-button svg polygon{fill:#0b81f6}.blue-w98.devui-selected-tag{background-color:#0b81f6}.aqua-w98{color:#39afcc;background-color:#fff;background-color:var(--devui-base-bg, #ffffff);border-width:1px;border-color:#39afcc}.aqua-w98 .remove-button svg polygon{fill:#39afcc}.aqua-w98.devui-selected-tag{background-color:#39afcc}.olivine-w98{color:#2fa898;background-color:#fff;background-color:var(--devui-base-bg, #ffffff);border-width:1px;border-color:#2fa898}.olivine-w98 .remove-button svg polygon{fill:#2fa898}.olivine-w98.devui-selected-tag{background-color:#2fa898}.green-w98{color:#4eb15e;background-color:#fff;background-color:var(--devui-base-bg, #ffffff);border-width:1px;border-color:#4eb15e}.green-w98 .remove-button svg polygon{fill:#4eb15e}.green-w98.devui-selected-tag{background-color:#4eb15e}.yellow-w98{color:#b08d1a;background-color:#fff;background-color:var(--devui-base-bg, #ffffff);border-width:1px;border-color:#b08d1a}.yellow-w98 .remove-button svg polygon{fill:#b08d1a}.yellow-w98.devui-selected-tag{background-color:#b08d1a}.orange-w98{color:#d47f35;background-color:#fff;background-color:var(--devui-base-bg, #ffffff);border-width:1px;border-color:#d47f35}.orange-w98 .remove-button svg polygon{fill:#d47f35}.orange-w98.devui-selected-tag{background-color:#d47f35}.red-w98{color:#e05a46;background-color:#fff;background-color:var(--devui-base-bg, #ffffff);border-width:1px;border-color:#e05a46}.red-w98 .remove-button svg polygon{fill:#e05a46}.red-w98.devui-selected-tag{background-color:#e05a46}.pink-w98{color:#f3689a;background-color:#fff;background-color:var(--devui-base-bg, #ffffff);border-width:1px;border-color:#f3689a}.pink-w98 .remove-button svg polygon{fill:#f3689a}.pink-w98.devui-selected-tag{background-color:#f3689a}.purple-w98{color:#b05bc1;background-color:#fff;background-color:var(--devui-base-bg, #ffffff);border-width:1px;border-color:#b05bc1}.purple-w98 .remove-button svg polygon{fill:#b05bc1}.purple-w98.devui-selected-tag{background-color:#b05bc1}.devui-selected-tag.devui-colorful-tag{color:#fff;color:var(--devui-base-bg, #ffffff)}.devui-selected-tag.devui-colorful-tag .remove-button svg polygon{fill:#fff;fill:var(--devui-base-bg, #ffffff)}.remove-button svg{vertical-align:text-top}.devui-tag-item.devui-checkable-tag{transition:color .3s cubic-bezier(.645,.045,.355,1),background-color .3s cubic-bezier(.645,.045,.355,1);transition:color var(--devui-animation-duration-slow, .3s) var(--devui-animation-ease-in-out-smooth, cubic-bezier(.645, .045, .355, 1)),background-color var(--devui-animation-duration-slow, .3s) var(--devui-animation-ease-in-out-smooth, cubic-bezier(.645, .045, .355, 1))}.devui-tag-item.devui-checkable-tag .content-wrapper{transition:opacity .3s cubic-bezier(.645,.045,.355,1);transition:opacity var(--devui-animation-duration-slow, .3s) var(--devui-animation-ease-in-out-smooth, cubic-bezier(.645, .045, .355, 1))}.devui-tag-item.devui-checkable-tag .remove-button svg polygon{transition:fill .3s cubic-bezier(.645,.045,.355,1);transition:fill var(--devui-animation-duration-slow, .3s) var(--devui-animation-ease-in-out-smooth, cubic-bezier(.645, .045, .355, 1))}.devui-max-width-tag{display:inline-block;overflow:hidden;white-space:nowrap;text-overflow:ellipsis}\n"], dependencies: [{ kind: "directive", type: i1.NgClass, selector: "[ngClass]", inputs: ["class", "ngClass"] }, { kind: "directive", type: i1.NgIf, selector: "[ngIf]", inputs: ["ngIf", "ngIfThen", "ngIfElse"] }, { kind: "directive", type: i1.NgTemplateOutlet, selector: "[ngTemplateOutlet]", inputs: ["ngTemplateOutletContext", "ngTemplateOutlet", "ngTemplateOutletInjector"] }, { kind: "directive", type: i1.NgStyle, selector: "[ngStyle]", inputs: ["ngStyle"] }] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "15.1.5", ngImport: i0, type: TagComponent, decorators: [{
            type: Component,
            args: [{ selector: 'd-tag', exportAs: 'Tag', preserveWhitespaces: false, template: "<span\n  class=\"devui-tag-item {{ labelStyle }}\"\n  [style.display]=\"deleteTag ? 'none' : 'block'\"\n  [ngClass]=\"{\n    'devui-colorful-tag': isColorfulTag,\n    'devui-selected-tag': checked,\n    'devui-deletable-tag': mode === 'closeable' || deletable,\n    'devui-checkable-tag': mode === 'checkable'\n  }\"\n  [ngStyle]=\"{\n    'border-color': customColor,\n    'background-color': isColorfulTag ? (checked ? customColor : '') : '',\n    color: isColorfulTag ? (checked ? '#fff' : customColor) : '',\n    cursor: this.mode === 'checkable' ? 'pointer' : ''\n  }\"\n  title=\"{{ titleContent ? titleContent : currentTag }}\"\n  (click)=\"tagClick()\"\n>\n  <div class=\"content-wrapper\" [ngStyle]=\"{ 'background-color': colorMap[labelStyle] || customColor }\"></div>\n  <span *ngIf=\"!customViewTemplate\" [class.devui-max-width-tag]=\"maxWidth\" [style.maxWidth]=\"maxWidth ? maxWidth : ''\">{{\n    currentTag\n  }}</span>\n  <ng-template *ngIf=\"customViewTemplate\" [ngTemplateOutlet]=\"customViewTemplate\" [ngTemplateOutletContext]=\"{ tag: tag }\"></ng-template>\n  <a\n    class=\"remove-button\"\n    [ngClass]=\"{ 'default-button': !isColorfulTag }\"\n    *ngIf=\"mode === 'closeable' || deletable\"\n    (click)=\"removeTag($event, tag)\"\n  >\n    <svg\n      *ngIf=\"isColorfulTag\"\n      width=\"12px\"\n      height=\"12px\"\n      viewBox=\"0 0 16 16\"\n      version=\"1.1\"\n      xmlns=\"http://www.w3.org/2000/svg\"\n      xmlns:xlink=\"http://www.w3.org/1999/xlink\"\n    >\n      <g stroke=\"none\" stroke-width=\"1\" fill=\"none\" fill-rule=\"evenodd\">\n        <polygon\n          [ngStyle]=\"{ fill: isColorfulTag ? (checked ? '#fff' : customColor) : '' }\"\n          fill=\"#293040\"\n          fill-rule=\"nonzero\"\n          points=\"8 6.58578644 12.2426407 2.34314575 13.6568542 3.75735931 9.41421356 8 13.6568542 12.2426407 12.2426407 13.6568542 8 9.41421356 3.75735931 13.6568542 2.34314575 12.2426407 6.58578644 8 2.34314575 3.75735931 3.75735931 2.34314575\"\n        ></polygon>\n      </g>\n    </svg>\n    <svg\n      *ngIf=\"!isColorfulTag\"\n      width=\"12px\"\n      height=\"12px\"\n      viewBox=\"0 0 12 12\"\n      version=\"1.1\"\n      xmlns=\"http://www.w3.org/2000/svg\"\n      xmlns:xlink=\"http://www.w3.org/1999/xlink\"\n    >\n      <g stroke=\"none\" stroke-width=\"1\" fill=\"none\" fill-rule=\"evenodd\">\n        <path\n          d=\"M8.86785321,3.13214679 C9.02624037,3.29053395 9.02624037,3.54733027 8.86785321,3.70571743 L6.573,6 L8.86785321,8.29428257 C9.02624037,8.45266973 9.02624037,8.70946605 8.86785321,8.86785321 C8.70946605,9.02624037 8.45266973,9.02624037 8.29428257,8.86785321 L6,6.573 L3.70571743,8.86785321 C3.54733027,9.02624037 3.29053395,9.02624037 3.13214679,8.86785321 C2.97375963,8.70946605 2.97375963,8.45266973 3.13214679,8.29428257 L5.427,6 L3.13214679,3.70571743 C2.97375963,3.54733027 2.97375963,3.29053395 3.13214679,3.13214679 C3.29053395,2.97375963 3.54733027,2.97375963 3.70571743,3.13214679 L6,5.427 L8.29428257,3.13214679 C8.45266973,2.97375963 8.70946605,2.97375963 8.86785321,3.13214679 Z\"\n          fill-rule=\"nonzero\"\n        ></path>\n      </g>\n    </svg>\n  </a>\n</span>\n", styles: [".devui-font-size-base{font-size:12px;font-size:var(--devui-font-size, 12px)}.devui-font-base{font-size:12px;font-size:var(--devui-font-size, 12px);font-weight:400;font-weight:var(--devui-font-content-weight, normal);line-height:1.5;line-height:var(--devui-line-height-base, 1.5)}.devui-font-size-modal-title{font-size:18px;font-size:var(--devui-font-size-modal-title, 18px)}.devui-font-modal-title{font-size:18px;font-size:var(--devui-font-size-modal-title, 18px);font-weight:700;font-weight:var(--devui-font-title-weight, bold);line-height:1.5;line-height:var(--devui-line-height-base, 1.5)}.devui-font-size-page-title{font-size:16px;font-size:var(--devui-font-size-page-title, 16px)}.devui-font-page-title{font-size:16px;font-size:var(--devui-font-size-page-title, 16px);font-weight:700;font-weight:var(--devui-font-title-weight, bold);line-height:1.5;line-height:var(--devui-line-height-base, 1.5)}.devui-font-size-secondary-title{font-size:14px;font-size:var(--devui-font-size-card-title, 14px)}.devui-font-secondary-title{font-size:14px;font-size:var(--devui-font-size-card-title, 14px);font-weight:700;font-weight:var(--devui-font-title-weight, bold);line-height:1.5;line-height:var(--devui-line-height-base, 1.5)}:host{display:inline-block;position:relative}.devui-tag-item{padding:0 8px;min-height:20px;font-size:12px;font-size:var(--devui-font-size, 12px);line-height:20px;color:#71757f;color:var(--devui-aide-text, #71757f);background-color:#e9edfa;background-color:var(--devui-label-bg, #e9edfa);border-radius:2px;border-radius:var(--devui-border-radius, 2px);border-width:0;border-style:solid;border-color:inherit;display:block;align-items:center;position:relative;cursor:default}.devui-tag-item .content-wrapper{pointer-events:none;position:absolute;width:100%;height:100%;border:1px solid transparent;top:0;left:0;opacity:0}.devui-tag-item span{vertical-align:0}.devui-tag-item:hover:not(.devui-colorful-tag):not(.devui-selected-tag).devui-checkable-tag{color:#252b3a;color:var(--devui-aide-text-hover, #252b3a)}.devui-tag-item:hover:not(.devui-colorful-tag):not(.devui-selected-tag).devui-checkable-tag .remove-button svg polygon{fill:#7693f5;fill:var(--devui-brand-hover, #7693f5)}.devui-tag-item:hover.devui-checkable-tag .content-wrapper{opacity:.08}.devui-tag-item.devui-selected-tag{color:#252b3a;color:var(--devui-aide-text-hover, #252b3a)}.devui-tag-item.devui-selected-tag .remove-button svg polygon{fill:#526ecc;fill:var(--devui-brand-active, #526ecc)}.devui-tag-item .remove-button{margin-left:12px;font-size:16px;font-size:var(--devui-font-size-icon, 16px);cursor:pointer;width:12px;height:12px;line-height:12px;border-radius:50%;display:inline-block;text-align:center;position:absolute;top:50%;transform:translateY(-50%)}.devui-tag-item .remove-button svg polygon{fill:#71757f;fill:var(--devui-icon-fill, #71757f)}.devui-tag-item .remove-button:hover{text-decoration:none;font-size:16px;font-size:var(--devui-font-size-icon, 16px)}.devui-tag-item .default-button{margin-left:12px;font-size:16px;font-size:var(--devui-font-size-icon, 16px);cursor:pointer;width:12px;height:12px;line-height:12px;background-color:#d7d8da;background-color:var(--devui-shape-icon-fill, #d7d8da);border-radius:50%;display:inline-block;text-align:center;transition:background-color cubic-bezier(.645,.045,.355,1) .3s;transition:background-color var(--devui-animation-ease-in-out-smooth, cubic-bezier(.645, .045, .355, 1)) var(--devui-animation-duration-slow, .3s)}.devui-tag-item .default-button svg path{fill:#fff;fill:var(--devui-light-text, #ffffff)}.devui-tag-item .default-button:hover{text-decoration:none;background-color:#babbc0;background-color:var(--devui-shape-icon-fill-hover, #babbc0)}.devui-deletable-tag{padding-right:32px}.devui-colorful-tag{height:18px;line-height:18px;border-width:1px;background-color:#fff;background-color:var(--devui-base-bg, #ffffff)}.blue-w98{color:#0b81f6;background-color:#fff;background-color:var(--devui-base-bg, #ffffff);border-width:1px;border-color:#0b81f6}.blue-w98 .remove-button svg polygon{fill:#0b81f6}.blue-w98.devui-selected-tag{background-color:#0b81f6}.aqua-w98{color:#39afcc;background-color:#fff;background-color:var(--devui-base-bg, #ffffff);border-width:1px;border-color:#39afcc}.aqua-w98 .remove-button svg polygon{fill:#39afcc}.aqua-w98.devui-selected-tag{background-color:#39afcc}.olivine-w98{color:#2fa898;background-color:#fff;background-color:var(--devui-base-bg, #ffffff);border-width:1px;border-color:#2fa898}.olivine-w98 .remove-button svg polygon{fill:#2fa898}.olivine-w98.devui-selected-tag{background-color:#2fa898}.green-w98{color:#4eb15e;background-color:#fff;background-color:var(--devui-base-bg, #ffffff);border-width:1px;border-color:#4eb15e}.green-w98 .remove-button svg polygon{fill:#4eb15e}.green-w98.devui-selected-tag{background-color:#4eb15e}.yellow-w98{color:#b08d1a;background-color:#fff;background-color:var(--devui-base-bg, #ffffff);border-width:1px;border-color:#b08d1a}.yellow-w98 .remove-button svg polygon{fill:#b08d1a}.yellow-w98.devui-selected-tag{background-color:#b08d1a}.orange-w98{color:#d47f35;background-color:#fff;background-color:var(--devui-base-bg, #ffffff);border-width:1px;border-color:#d47f35}.orange-w98 .remove-button svg polygon{fill:#d47f35}.orange-w98.devui-selected-tag{background-color:#d47f35}.red-w98{color:#e05a46;background-color:#fff;background-color:var(--devui-base-bg, #ffffff);border-width:1px;border-color:#e05a46}.red-w98 .remove-button svg polygon{fill:#e05a46}.red-w98.devui-selected-tag{background-color:#e05a46}.pink-w98{color:#f3689a;background-color:#fff;background-color:var(--devui-base-bg, #ffffff);border-width:1px;border-color:#f3689a}.pink-w98 .remove-button svg polygon{fill:#f3689a}.pink-w98.devui-selected-tag{background-color:#f3689a}.purple-w98{color:#b05bc1;background-color:#fff;background-color:var(--devui-base-bg, #ffffff);border-width:1px;border-color:#b05bc1}.purple-w98 .remove-button svg polygon{fill:#b05bc1}.purple-w98.devui-selected-tag{background-color:#b05bc1}.devui-selected-tag.devui-colorful-tag{color:#fff;color:var(--devui-base-bg, #ffffff)}.devui-selected-tag.devui-colorful-tag .remove-button svg polygon{fill:#fff;fill:var(--devui-base-bg, #ffffff)}.remove-button svg{vertical-align:text-top}.devui-tag-item.devui-checkable-tag{transition:color .3s cubic-bezier(.645,.045,.355,1),background-color .3s cubic-bezier(.645,.045,.355,1);transition:color var(--devui-animation-duration-slow, .3s) var(--devui-animation-ease-in-out-smooth, cubic-bezier(.645, .045, .355, 1)),background-color var(--devui-animation-duration-slow, .3s) var(--devui-animation-ease-in-out-smooth, cubic-bezier(.645, .045, .355, 1))}.devui-tag-item.devui-checkable-tag .content-wrapper{transition:opacity .3s cubic-bezier(.645,.045,.355,1);transition:opacity var(--devui-animation-duration-slow, .3s) var(--devui-animation-ease-in-out-smooth, cubic-bezier(.645, .045, .355, 1))}.devui-tag-item.devui-checkable-tag .remove-button svg polygon{transition:fill .3s cubic-bezier(.645,.045,.355,1);transition:fill var(--devui-animation-duration-slow, .3s) var(--devui-animation-ease-in-out-smooth, cubic-bezier(.645, .045, .355, 1))}.devui-max-width-tag{display:inline-block;overflow:hidden;white-space:nowrap;text-overflow:ellipsis}\n"] }]
        }], propDecorators: { tag: [{
                type: Input
            }], labelStyle: [{
                type: Input
            }], customColor: [{
                type: Input
            }], deletable: [{
                type: Input
            }], titleContent: [{
                type: Input
            }], mode: [{
                type: Input
            }], checked: [{
                type: Input
            }], maxWidth: [{
                type: Input
            }], customViewTemplate: [{
                type: Input
            }], beforeDelete: [{
                type: Input
            }], tagDelete: [{
                type: Output
            }], checkedChange: [{
                type: Output
            }] } });

class TagsComponent {
    constructor(cdr) {
        this.cdr = cdr;
        /**
         * 【必选】记录输入的标签
         */
        this.tags = [];
        /**
         * 【可选】使用的属性名
         */
        this.displayProperty = '';
        /**
         * @deprecated
         */
        this.deletable = false;
        this.mode = 'default';
        this.titleProperty = '';
        this.hideBeyondTags = false;
        /**
         * tag被删除后触发
         */
        this.tagDelete = new EventEmitter();
        this.checkedChange = new EventEmitter();
        /**
         * 多标签超出显示相关数据
         */
        this.showTags = [];
        this.beyondTags = [];
        this.showMore = false;
        this.MORE_TAG_WIDTH = 30;
        this.TAG_MARGIN = 4;
    }
    ngOnInit() {
        this.maxShowNumber = 0;
        // TODO: 使用cloneDeep导致category-search卡顿，lodash-es报Illegal invocation非法调用错误，需调查原因，暂用循环方式替代深拷贝
        if (this.hideBeyondTags) {
            this.tags.forEach((item) => this.showTags.push(typeof item === 'object' ? { ...item } : item));
        }
    }
    ngAfterViewInit() {
        if (this.hideBeyondTags) {
            this.calculateHideTagsStatus();
        }
    }
    ngOnChanges(changes) {
        if (this.hideBeyondTags && changes['tags'] && !changes['tags'].firstChange) {
            this.maxShowNumber = 0;
            this.showTags = [...this.tags];
            this.calculateHideTagsStatus();
        }
    }
    calculateHideTagsStatus() {
        this.cdr.detectChanges();
        this.tagsFatherWidth = this.tagsElement.nativeElement.getBoundingClientRect().width;
        let curWidth = 0;
        const viewChildrenArr = this.viewChildren.toArray();
        for (let i = 0; i < viewChildrenArr.length; i++) {
            if (curWidth + viewChildrenArr[i].nativeElement.offsetWidth + this.TAG_MARGIN < this.tagsFatherWidth - this.MORE_TAG_WIDTH) {
                curWidth += viewChildrenArr[i].nativeElement.offsetWidth;
                curWidth += this.TAG_MARGIN;
                this.maxShowNumber = i + 1;
            }
            else {
                break;
            }
        }
        if (this.maxShowNumber !== this.tags.length) {
            this.showMore = true;
            this.beyondTags = this.showTags.slice(this.maxShowNumber);
            this.showTags.splice(this.maxShowNumber);
            this.cdr.detectChanges();
        }
        else {
            this.showMore = false;
        }
    }
    removeTag($event, tag, index) {
        this.tagDelete.emit({ tag: tag, index: index, event: $event });
    }
    tagChecked($event, tag, index) {
        this.checkedChange.emit({ tag: tag, index: index, checked: $event });
    }
}
TagsComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "15.1.5", ngImport: i0, type: TagsComponent, deps: [{ token: i0.ChangeDetectorRef }], target: i0.ɵɵFactoryTarget.Component });
TagsComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "15.1.5", type: TagsComponent, selector: "d-tags", inputs: { tags: "tags", displayProperty: "displayProperty", deletable: "deletable", mode: "mode", titleProperty: "titleProperty", hideBeyondTags: "hideBeyondTags", beforeDelete: "beforeDelete" }, outputs: { tagDelete: "tagDelete", checkedChange: "checkedChange" }, queries: [{ propertyName: "customViewTemplate", first: true, predicate: TemplateRef, descendants: true }], viewQueries: [{ propertyName: "tagsElement", first: true, predicate: ["tagsElement"], descendants: true }, { propertyName: "viewChildren", predicate: ["tagElement"], descendants: true, read: ElementRef }], exportAs: ["Tags"], usesOnChanges: true, ngImport: i0, template: "<div class=\"devui-tags\" #tagsElement>\n  <d-tag\n    #tagElement\n    *ngFor=\"let tag of hideBeyondTags ? showTags : tags; let index = index\"\n    [tag]=\"displayProperty ? tag[displayProperty] : tag\"\n    [mode]=\"mode\"\n    [deletable]=\"deletable\"\n    [checked]=\"tag['checked']\"\n    [labelStyle]=\"tag['labelStyle']\"\n    [customColor]=\"tag['customColor']\"\n    [titleContent]=\"titleProperty ? tag[titleProperty] : displayProperty ? tag[displayProperty] : tag\"\n    [customViewTemplate]=\"customViewTemplate\"\n    [beforeDelete]=\"beforeDelete\"\n    (tagDelete)=\"removeTag($event, tag, index)\"\n    (checkedChange)=\"tagChecked($event, tag, index)\"\n  >\n  </d-tag>\n  <d-tag\n    class=\"show-more-tag\"\n    *ngIf=\"hideBeyondTags && showMore\"\n    dPopover\n    [content]=\"beyondTagsTpl\"\n    [controlled]=\"true\"\n    [tag]=\"'+ ' + beyondTags.length\"\n    [mode]=\"'checkable'\"\n    [popoverStyle]=\"{ backgroundColor: 'white', color: 'black' }\"\n  ></d-tag>\n</div>\n\n<ng-template #beyondTagsTpl>\n  <div class=\"beyond-tags-wrapper\">\n    <d-tag\n      class=\"beyond-tag-style\"\n      *ngFor=\"let tag of beyondTags; let index = index\"\n      [tag]=\"displayProperty ? tag[displayProperty] : tag\"\n      [mode]=\"mode\"\n      [deletable]=\"deletable\"\n      [checked]=\"tag['checked']\"\n      [labelStyle]=\"tag['labelStyle']\"\n      [customColor]=\"tag['customColor']\"\n      [titleContent]=\"titleProperty ? tag[titleProperty] : displayProperty ? tag[displayProperty] : tag\"\n      [customViewTemplate]=\"customViewTemplate\"\n      [beforeDelete]=\"beforeDelete\"\n      (tagDelete)=\"removeTag($event, tag, index)\"\n      (checkedChange)=\"tagChecked($event, tag, index)\"\n    >\n    </d-tag>\n  </div>\n</ng-template>\n", styles: [".devui-tags{overflow:hidden;word-wrap:break-word;height:100%;line-height:24px}.beyond-tags-wrapper{max-width:300px;margin-top:8px;max-height:300px;overflow:auto}.beyond-tags-wrapper .beyond-tag-style{margin-bottom:8px}.beyond-tags-wrapper d-tag:not(:last-of-type){margin-right:8px}d-tag:not(:last-of-type){margin-right:4px}\n"], dependencies: [{ kind: "directive", type: i1.NgForOf, selector: "[ngFor][ngForOf]", inputs: ["ngForOf", "ngForTrackBy", "ngForTemplate"] }, { kind: "directive", type: i1.NgIf, selector: "[ngIf]", inputs: ["ngIf", "ngIfThen", "ngIfElse"] }, { kind: "directive", type: i2.PopoverDirective, selector: "[dPopover]", inputs: ["content", "controlled", "position", "showAnimation", "showAnimate", "scrollElement", "appendToBody", "zIndex", "popType", "popMaxWidth", "trigger", "hoverToContent", "hoverDelayTime", "popoverStyle", "mouseEnterDelay", "mouseLeaveDelay", "visible"], exportAs: ["dPopover"] }, { kind: "component", type: TagComponent, selector: "d-tag", inputs: ["tag", "labelStyle", "customColor", "deletable", "titleContent", "mode", "checked", "maxWidth", "customViewTemplate", "beforeDelete"], outputs: ["tagDelete", "checkedChange"], exportAs: ["Tag"] }] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "15.1.5", ngImport: i0, type: TagsComponent, decorators: [{
            type: Component,
            args: [{ selector: 'd-tags', exportAs: 'Tags', preserveWhitespaces: false, template: "<div class=\"devui-tags\" #tagsElement>\n  <d-tag\n    #tagElement\n    *ngFor=\"let tag of hideBeyondTags ? showTags : tags; let index = index\"\n    [tag]=\"displayProperty ? tag[displayProperty] : tag\"\n    [mode]=\"mode\"\n    [deletable]=\"deletable\"\n    [checked]=\"tag['checked']\"\n    [labelStyle]=\"tag['labelStyle']\"\n    [customColor]=\"tag['customColor']\"\n    [titleContent]=\"titleProperty ? tag[titleProperty] : displayProperty ? tag[displayProperty] : tag\"\n    [customViewTemplate]=\"customViewTemplate\"\n    [beforeDelete]=\"beforeDelete\"\n    (tagDelete)=\"removeTag($event, tag, index)\"\n    (checkedChange)=\"tagChecked($event, tag, index)\"\n  >\n  </d-tag>\n  <d-tag\n    class=\"show-more-tag\"\n    *ngIf=\"hideBeyondTags && showMore\"\n    dPopover\n    [content]=\"beyondTagsTpl\"\n    [controlled]=\"true\"\n    [tag]=\"'+ ' + beyondTags.length\"\n    [mode]=\"'checkable'\"\n    [popoverStyle]=\"{ backgroundColor: 'white', color: 'black' }\"\n  ></d-tag>\n</div>\n\n<ng-template #beyondTagsTpl>\n  <div class=\"beyond-tags-wrapper\">\n    <d-tag\n      class=\"beyond-tag-style\"\n      *ngFor=\"let tag of beyondTags; let index = index\"\n      [tag]=\"displayProperty ? tag[displayProperty] : tag\"\n      [mode]=\"mode\"\n      [deletable]=\"deletable\"\n      [checked]=\"tag['checked']\"\n      [labelStyle]=\"tag['labelStyle']\"\n      [customColor]=\"tag['customColor']\"\n      [titleContent]=\"titleProperty ? tag[titleProperty] : displayProperty ? tag[displayProperty] : tag\"\n      [customViewTemplate]=\"customViewTemplate\"\n      [beforeDelete]=\"beforeDelete\"\n      (tagDelete)=\"removeTag($event, tag, index)\"\n      (checkedChange)=\"tagChecked($event, tag, index)\"\n    >\n    </d-tag>\n  </div>\n</ng-template>\n", styles: [".devui-tags{overflow:hidden;word-wrap:break-word;height:100%;line-height:24px}.beyond-tags-wrapper{max-width:300px;margin-top:8px;max-height:300px;overflow:auto}.beyond-tags-wrapper .beyond-tag-style{margin-bottom:8px}.beyond-tags-wrapper d-tag:not(:last-of-type){margin-right:8px}d-tag:not(:last-of-type){margin-right:4px}\n"] }]
        }], ctorParameters: function () { return [{ type: i0.ChangeDetectorRef }]; }, propDecorators: { tags: [{
                type: Input
            }], displayProperty: [{
                type: Input
            }], deletable: [{
                type: Input
            }], mode: [{
                type: Input
            }], titleProperty: [{
                type: Input
            }], hideBeyondTags: [{
                type: Input
            }], beforeDelete: [{
                type: Input
            }], customViewTemplate: [{
                type: ContentChild,
                args: [TemplateRef]
            }], tagsElement: [{
                type: ViewChild,
                args: ['tagsElement']
            }], viewChildren: [{
                type: ViewChildren,
                args: ['tagElement', { read: ElementRef }]
            }], tagDelete: [{
                type: Output
            }], checkedChange: [{
                type: Output
            }] } });

class TagsModule {
}
TagsModule.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "15.1.5", ngImport: i0, type: TagsModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule });
TagsModule.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "15.1.5", ngImport: i0, type: TagsModule, declarations: [TagsComponent,
        TagComponent], imports: [CommonModule,
        FormsModule,
        PopoverModule], exports: [TagsComponent,
        TagComponent] });
TagsModule.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "15.1.5", ngImport: i0, type: TagsModule, imports: [CommonModule,
        FormsModule,
        PopoverModule] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "15.1.5", ngImport: i0, type: TagsModule, decorators: [{
            type: NgModule,
            args: [{
                    imports: [
                        CommonModule,
                        FormsModule,
                        PopoverModule
                    ],
                    exports: [
                        TagsComponent,
                        TagComponent
                    ],
                    declarations: [
                        TagsComponent,
                        TagComponent
                    ]
                }]
        }] });

/**
 * Generated bundle index. Do not edit.
 */

export { TagComponent, TagsComponent, TagsModule };
//# sourceMappingURL=ng-devui-tags.mjs.map
